@@ -23,7 +23,7 @@ from pdm.cli.utils import (
     set_env_in_reg,
 )
 from pdm.environments import BareEnvironment
-from pdm.exceptions import PdmException, PdmUsageError, ProjectError
+from pdm.exceptions import PdmException, PdmUsageError, ProjectError, ResolutionError
 from pdm.models.candidates import Candidate
 from pdm.models.markers import EnvSpec
 from pdm.models.repositories import LockedRepository, Package
@@ -79,7 +79,8 @@ def do_lock(
     if groups is None:
         groups = list(project.iter_groups())
     if not requirements:
-        requirements = [r for group in groups for r in project.get_dependencies(group)]
+        all_deps = project._resolve_dependencies(groups)
+        requirements = [r for group in groups for r in project.get_dependencies(group, all_deps)]
     ui = project.core.ui
     supports_env_spec = "env_spec" in inspect.signature(project.get_provider).parameters
     # The repository to store the lock result
@@ -143,11 +144,13 @@ def do_lock(
                     f"[success]`strategy.resolve_max_rounds`[/] config.",
                     err=True,
                 )
-                raise
+                raise ResolutionError(
+                    f"The dependency resolution exceeds the maximum loop depth of {resolve_max_rounds}"
+                ) from None
             except ResolutionImpossible as err:
                 reporter.update(f"{termui.Emoji.LOCK} Lock failed.", info="", completed=1)
                 ui.error(format_resolution_impossible(err))
-                raise ResolutionImpossible("Unable to find a resolution") from None
+                raise ResolutionError("Unable to find a resolution") from None
             else:
                 groups = list(set(groups) | collected_groups)
                 data = result_repo.format_lockfile(groups=groups, strategy=lock_strategy)
@@ -200,9 +203,9 @@ def resolve_from_lockfile(
 
         with ui.logging("install-resolve"):
             strategies = project.lockfile.strategy.copy()
-            if FLAG_INHERIT_METADATA in strategies and groups is not None:
+            if FLAG_INHERIT_METADATA in strategies and groups is not None and not project.config["use_uv"]:
                 return locked_repo.evaluate_candidates(groups)
-            strategies.update((FLAG_STATIC_URLS, FLAG_INHERIT_METADATA))
+            strategies.add(FLAG_STATIC_URLS)
             resolver = project.get_resolver()(
                 environment=project.environment,
                 requirements=reqs,
@@ -265,6 +268,7 @@ def do_sync(
     selection: GroupSelection,
     dry_run: bool = False,
     clean: bool = False,
+    quiet: bool = False,
     requirements: list[Requirement] | None = None,
     tracked_names: Collection[str] | None = None,
     no_editable: bool | Collection[str] = False,
@@ -279,12 +283,13 @@ def do_sync(
     if requirements is None:
         requirements = []
         selection.validate()
+        all_deps = project._resolve_dependencies(list(selection))
         for group in selection:
-            requirements.extend(project.get_dependencies(group))
+            requirements.extend(project.get_dependencies(group, all_deps))
     packages = list(resolve_from_lockfile(project, requirements, groups=list(selection)))
     if tracked_names and dry_run:
         packages = [p for p in packages if p.candidate.identify() in tracked_names]
-    synchronizer = project.get_synchronizer()(
+    synchronizer = project.get_synchronizer(quiet=quiet)(
         project.environment,
         clean=clean,
         dry_run=dry_run,
@@ -294,7 +299,6 @@ def do_sync(
         only_keep=only_keep,
         fail_fast=fail_fast,
         packages=packages,
-        requirements=requirements,
     )
     with project.core.ui.logging("install"):
         hooks.try_emit("pre_install", packages=packages, dry_run=dry_run)
